@@ -5,7 +5,7 @@ This chart provides a library to bootstrap a Plone deployment on a Kubernetes cl
 
 It provides
 
-* Backend (for API with `plone.volto` or as Classic-UI)
+* Backend (as API with `plone.volto` or as Classic-UI)
 * Frontend (Plone-Volto, a ReactJS based user interface)
 * Varnish using kube-httpcache. It includes a way to invalidate varnish cluster (optional)
 
@@ -73,8 +73,8 @@ Clone the repository and install the dependencies:
 ```
 
 nvm use lts/*
-npm install yarn
-projen
+corepack enable
+npx projen
 
 ```
 
@@ -83,42 +83,6 @@ Then run the following command to run the test:
 ```bash
 npx projen test
 ```
-
-### Feature Wishlist:
-
-Each step need to be implemented with tests!
-
-* [x] Support Variants for ClassicUI or Volto
-* [ ] Start Backend
-
-  * [x] deployment
-  * [x] service
-  * [x] pdb
-  * [ ] init container running `plone-site-create`
-  * [x] lifecycle checks (readiness, liveness)
-  * [x] generic way to inject sidecars
-  * [ ] metrics sidecar
-* [ ] Start Frontend
-
-  * [x] deployment
-  * [x] service
-  * [x] pdb
-  * [x] lifecycle checks (readiness, liveness)
-  * [x] generic way to inject sidecars
-  * [ ] metrics sidecar
-* [x] Start Varnish (using `kube-httpcache`) optional in separate chart
-
-  * [x] provide a default VCL for Volto with routing to backend and frontend
-  * [ ] provide a default VCL for ClassicUI
-* [ ] Configure Ingress, optional in separate chart
-
-  * [ ] Traefik
-  * [ ] Konq
-* [ ] Release packages for other Languages
-
-  * [x] Python
-  * [ ] Golang
-  * [ ] Java
 '''
 from pkgutil import extend_path
 __path__ = extend_path(__path__, __name__)
@@ -152,7 +116,7 @@ def check_type(argname: str, value: object, expected_type: typing.Any) -> typing
 
 from ._jsii import *
 
-import cdk8s_plus_24 as _cdk8s_plus_24_d27940f9
+import cdk8s_plus_29 as _cdk8s_plus_29_3c4c50bd
 import constructs as _constructs_77d1e7e8
 
 
@@ -251,7 +215,7 @@ class PloneBaseOptions:
     def __init__(
         self,
         *,
-        environment: typing.Optional[_cdk8s_plus_24_d27940f9.Env] = None,
+        environment: typing.Optional[_cdk8s_plus_29_3c4c50bd.Env] = None,
         image: typing.Optional[builtins.str] = None,
         image_pull_policy: typing.Optional[builtins.str] = None,
         limit_cpu: typing.Optional[builtins.str] = None,
@@ -369,9 +333,9 @@ class PloneBaseOptions:
             self._values["request_memory"] = request_memory
 
     @builtins.property
-    def environment(self) -> typing.Optional[_cdk8s_plus_24_d27940f9.Env]:
+    def environment(self) -> typing.Optional[_cdk8s_plus_29_3c4c50bd.Env]:
         result = self._values.get("environment")
-        return typing.cast(typing.Optional[_cdk8s_plus_24_d27940f9.Env], result)
+        return typing.cast(typing.Optional[_cdk8s_plus_29_3c4c50bd.Env], result)
 
     @builtins.property
     def image(self) -> typing.Optional[builtins.str]:
@@ -812,7 +776,7 @@ def _typecheckingstub__543cbcb1139deb4ce75315c33bb5ebd6fd98851d9416a0f8e2c5cd960
 
 def _typecheckingstub__cd9cf17a63ac3f69f433db3caa859d98a750929386f09ada26dd0fd212b3ec78(
     *,
-    environment: typing.Optional[_cdk8s_plus_24_d27940f9.Env] = None,
+    environment: typing.Optional[_cdk8s_plus_29_3c4c50bd.Env] = None,
     image: typing.Optional[builtins.str] = None,
     image_pull_policy: typing.Optional[builtins.str] = None,
     limit_cpu: typing.Optional[builtins.str] = None,
